#!/bin/bash -e

#########################################################################
# A simple script to change a directory of one type of images to another.
#   -- Garrett LeSage <garrett@linux.com>
#########################################################################
#		Yes, this is a hack, but it works pretty well.
#
#		  Note: you probably want to get "tidy" at:
#          http://www.w3.org/People/Raggett/tidy/
#	  (or just "apt-get install tidy" if using Debian)
#########################################################################

# Version of imgconvert
IMGCONVERT_VERSION=0.4

# Number of pictures per row
LOOPNUM=4

# The file format you wish to change
FROM=jpg

# Options for "convert"
CONVERT_OPTIONS='-quality 75'

# Pull the directory name for the title
DIR_NAME=`pwd`
DIR_NAME=`basename "$DIR_NAME"`

# Site name for the title
SITENAME="And.org"

# This is for the <title> area, and automatically pulls fromt the sitename,
# which can be edited directly above
TOPTITLE="$SITENAME - "

# General title
TITLE="Pics: $DIR_NAME"

# Description
DESC="Pictures about: $DIR_NAME"

# Instructions for the viewer
INSTR="\
Clicking on the thumbnail will download the 40% version of the image.<br>\
File sizes are located next to each link, all images but the \"Full Size\" image
have been reduced to 75% quality."

# Page colors, fonts, etc
TEXT="#000000"
BGCOLOR="#ffffff"
LINK="#5555aa"
ALINK="#9999AA"
VLINK="#bbbbee"
FONT_FAMILY="helvetica,arial,sans-serif"

# This credits imgconvert, if you don't want to give credit (for whatever
# reason, I don't know), you can turn it off here. Default is "1". "0" will
# turn off the credit at the bottom.
CREDIT=1

#########################################################################
# The actual convertion stuff
# You can edit stuff below here to change how this works, or just stick
# with the variables above (which should be good for most people
#########################################################################

echo Running $0
echo

if [ ! -s "img_thumb/" ] 
then
	mkdir img_thumb || true
fi

if [ ! -s "img_640/" ] 
then 	
	mkdir img_640 || true
fi

if [ ! -s "img_800/" ] 
then 	
	mkdir img_800 || true
fi

if [ ! -s "img_1024/" ] 
then 	
	mkdir img_1024 || true
fi

### Header
echo "<html><head><title>$TOPTITLE$TITLE</title><style type=\"text/css\">" > index.html
echo "H1, P {font-family: $FONT_FAMILY}" >> index.html
echo "</style><meta name=\"generator\" content=\"imgconvert $IMGCONVERT_VERSION - http://linuxart.com/imgconvert/\"></head>" >> index.html
echo "<body bgcolor=\"$BGCOLOR\" text=\"$TEXT\"" >> index.html
echo "vlink=\"$VLINK\" link=\"$LINK\">" >> index.html
echo "<h1 align=\"center\">$TITLE</h1>" >> index.html
echo "<p align=\"center\">$DESC" >> index.html
echo "<p align=\"center\"><small>Instructions: <br> $INSTR</small>" >> index.html
echo "<p align=\"center\">[<a href=\"../\">back</a>]" >> index.html

### End Header

TABLE_START="<center><table border=0 cellspacing=5 cellpadding=7 align=center><tr>"

function conv_filename2url ()
{
	perl -e '
 $_ = $ARGV[0];
 if (($ARGV[1] ne "") && ($ARGV[2] ne ""))
 {
   s/[.]$ARGV[1]$/-$ARGV[2].$ARGV[1]/;
 }
 s/([^[:alnum:]:._-])/sprintf("%%%02x", ord($1))/eg;
 print;
'                 "$1" "$2" "$3"
}

function conv_name2id ()
{
	perl -e '
 $_ = $ARGV[0];
 s/([^[:alnum:]:._])/-/g;
 print;
'                 "$1"
}

function img_width_height ()
{
	identify -verbose "$1" | \
          perl -nle '/Geometry: (\d+)x(\d+)/ && \
                     print "width=\"$1\" height=\"$2\""'
}

CONVERT_OPTIONS='-quality 75 -scale'
COUNT=0
DONE=0
# Can't have \n in name...
LC_ALL=C \ls *.$FROM | perl -e \
 '@a = <>; for (@a) { s/(.*)[.]jpg$/$1/ } for (sort @a) { print }' | \
while read i; do
	COUNTLOOP=$( expr $COUNT '%' $LOOPNUM || true )

	COUNT=`expr $COUNT + 1`

	echo -n Converting '"'$i'"'... '('
	if [ $COUNTLOOP -eq 0 ]
	then
		# echo "</tr></table></center>$TABLE_START" >> index.html
		if [ $DONE -eq 0 ]
		then
			echo "$TABLE_START" >> index.html
			DONE=1
		else
			echo "</tr><tr>" >> index.html
		fi
		echo -n '[' $COUNT '])'
	else
		echo -n '' $COUNT ')'
	fi
	
	echo "<td>" >> index.html

	_full_size_human="$i"
	i="$i.jpg"

	_thumb_url=`conv_filename2url "$i" $FROM thumb`
	_thumb=`basename "$i" .$FROM`-thumb.$FROM
	if [ ! -s "img_thumb/$_thumb" ] 
	then
		echo -en "\t - " thumb 
		convert $CONVERT_OPTIONS 10% "$i" "img_thumb/$_thumb"
	fi
	
	_640_url=`conv_filename2url "$i" $FROM 640x480`
	_640=`basename "$i" .$FROM`-640x480.$FROM
	if [ ! -s "img_640/$_640" ] 
	then
		echo -en " " '40%' 
		convert $CONVERT_OPTIONS 40% "$i" "img_640/$_640"
	fi
	
	_800_url=`conv_filename2url "$i" $FROM 800x600`
	_800=`basename "$i" .$FROM`-800x600.$FROM
	if [ ! -s "img_800/$_800" ]
	then
		echo -en " " '50%' 
		convert $CONVERT_OPTIONS 50% "$i" "img_800/$_800"
	fi
	
	_1024_url=`conv_filename2url "$i" $FROM 1024x768`
	_1024=`basename "$i" .$FROM`-1024x768.$FROM
	if [ ! -s "img_1024/$_1024" ]
	then
		echo -en " " '64%' 
		convert $CONVERT_OPTIONS 64% "$i" "img_1024/$_1024"
	fi

	echo "" 
	_full_size_url=`conv_filename2url "$i"`
	_full_size_id=`conv_name2id "$_full_size_human"`
	
echo "<p align=\"center\">" >> index.html
echo "<a id=\"$_full_size_id\">" >> index.html
echo "<a id=\"$COUNT\">" >> index.html
echo "<strong>$COUNT</strong>: <small>$_full_size_human</small>" >> index.html
echo "<br>" >> index.html
echo "<a href=\"img_640/$_640_url\"><img src=\"img_thumb/$_thumb_url\"" >> index.html
img_width_height "img_thumb/$_thumb" >> index.html
echo "alt=\"$i\"></a><br>" >> index.html
echo "<font size=\"2\">" >> index.html

echo "<a href=\"img_640/$_640_url\">40%</a>" >> index.html
SIZE=`du -sh "img_640/$_640" | cut -f 1`
echo "(${SIZE})  " >> index.html

echo "<br>" >> index.html

echo "<a href=\"img_800/$_800_url\">50%</a>" >> index.html
SIZE=`du -sh "img_800/$_800" | cut -f 1`
echo "(${SIZE})  " >> index.html

echo "<br>" >> index.html

echo "<a href=\"img_1024/$_1024_url\">64%</a>" >> index.html
SIZE=`du -sh "img_1024/$_1024" | cut -f 1`
echo "(${SIZE})  " >> index.html

echo "<br>" >> index.html

echo "<a href=\"$_full_size_url\">Full Size</a>" >> index.html
SIZE=`du -sh "./$i" | cut -f 1`
echo "(${SIZE})  " >> index.html

echo "</font>" >> index.html

echo "</a>" >> index.html
echo "</a>" >> index.html
echo "</p>" >> index.html
echo "</td>" >> index.html

done;

echo
echo
echo "-----------------------------------------------------------------------"
echo "| Finished Converting"
echo "-----------------------------------------------------------------------"

echo "</td></tr></table>" >> index.html
echo "<p align=\"center\">[<a href=\"../\">back</a>]" >> index.html

#########################################################################
# Tagline at the bottom
# you can turn this off by toggling the "CREDIT" variable at the top
#########################################################################

if [ $CREDIT -eq 1 ]
	then
		echo "<p align=\"center\"><small>Generated by " >> index.html
		echo "<a href=\"http://www.and.org/imgconvert/\">imgconvert" >> index.html
		echo " $IMGCONVERT_VERSION</a></small>" >> index.html
fi

############################

echo "</body></html>" >> index.html

# tidy -wrap 3000 -m -i -q -raw index.html

exit;
